@@ -55,7 +55,7 @@ class OwnersManual extends CGExtensions {
   }
 
   function GetVersion() {
-    return '1.0.1';
+    return '1.0.2';
   }
   
   function GetHelp() {
@@ -117,5 +117,9 @@ class OwnersManual extends CGExtensions {
   function UninstallPreMessage() {
     return $this->Lang('really_uninstall');
   }
+
+  function AdminStyle() {
+    return '#man_content_div li {list-style: disc outside none; width: 100%}';
+  }
 }
 ?>
